@@ -765,17 +765,17 @@ END
       "rpm2cpio words-3.0-24.fc23.noarch.rpm | \(cd /; cpio -idmv\)");
    ($stdout,$stderr)=$handle->cmd("chmod -v 755 /usr/share/dict/",
       '__display__');
-   my $pasgen="http://search.cpan.org/CPAN/authors/id/T/TJ/TJENNESS/".
-         "Crypt-PassGen-0.06.tar.gz";
-   ($stdout,$stderr)=$handle->cmd(
-      "wget --random-wait --progress=dot ".$pasgen,
-      '__display__');
-   ($stdout,$stderr)=$handle->cmd("tar xvf Crypt-PassGen-0.06.tar.gz",
-      '__display__');
-   ($stdout,$stderr)=$handle->cwd("Crypt-PassGen-0.06");
-   ($stdout,$stderr)=$handle->cmd("perl Makefile.PL",'__display__');
-   ($stdout,$stderr)=$handle->cmd("make install",'__display__');
-   ($stdout,$stderr)=$handle->cwd("..");
+   #my $pasgen="http://search.cpan.org/CPAN/authors/id/T/TJ/TJENNESS/".
+   #      "Crypt-PassGen-0.06.tar.gz";
+   #($stdout,$stderr)=$handle->cmd(
+   #   "wget --random-wait --progress=dot ".$pasgen,
+   #   '__display__');
+   #($stdout,$stderr)=$handle->cmd("tar xvf Crypt-PassGen-0.06.tar.gz",
+   #   '__display__');
+   #($stdout,$stderr)=$handle->cwd("Crypt-PassGen-0.06");
+   #($stdout,$stderr)=$handle->cmd("perl Makefile.PL",'__display__');
+   #($stdout,$stderr)=$handle->cmd("make install",'__display__');
+   #($stdout,$stderr)=$handle->cwd("..");
    my $install_fullautoapi=<<'END';
 
           o o    o .oPYo. ooooo    .oo o     o     o o    o .oPYo.
@@ -868,6 +868,17 @@ END
    }
    $show=<<END;
 
+########################################
+
+   INSTALLING Crypt::PassGen
+
+########################################
+END
+   $handle->cmd_raw("${sudo}cpan Crypt::PassGen",
+      '__display__');
+   print "\n";
+   $show=<<END;
+
 ########################################
 
    INSTALLING Catalyst::Controller::HTML::FormFu
@@ -1252,6 +1263,8 @@ END
    ($stdout,$stderr)=$handle->cmd("catalyst.pl FullAutoAPI",'__display__');
    ($stdout,$stderr)=$handle->cwd("FullAutoAPI");
    ($stdout,$stderr)=$handle->cmd("perl Makefile.PL",'__display__');
+   # http://www.catalystframework.org/calendar/2011/15
+   # http://search.cpan.org/~bobtfish/Catalyst-Plugin-Authentication-0.10023/
    my $pm_path="./lib/FullAutoAPI.pm";
    $ad="    Session%NL%".
        "    Session::Store::Memcached%NL%".
@@ -1288,6 +1301,8 @@ END
        "    },";
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i '/Send X-Catalyst header/a$ad' $pm_path");
+   $handle->cmd_raw(
+       "${sudo}sed -i 's/\\(^use_request_uri$\\\)/    \\1/' $pm_path");
    $handle->cmd_raw(
        "${sudo}sed -i 's/\\(^Session$\\\)/    \\1/' $pm_path");
    $handle->cmd_raw(
@@ -1299,7 +1314,7 @@ END
    ($stdout,$stderr)=$handle->cmd("touch root/login/login.tt",
       '__display__');
    my $content=<<'ENDD';
-[% META title = 'Welcome to FullAuto: Please Log In' %]
+[% META title = 'Welcome to the FullAuto API Management Dashboard: Please Log In' %]
 <div>
     [% FOR field IN login_form.error_fields %]
         [% FOR error IN field.errors %]
@@ -1327,7 +1342,166 @@ END
 </div>
 ENDD
    ($stdout,$stderr)=$handle->cmd(
-      "echo -e \"$content\" > root/src/login/login.tt2");
+      "echo -e \"$content\" > root/login/login.tt");
+   ($stdout,$stderr)=$handle->cmd("mkdir -vp root/email",'__display__');
+   ($stdout,$stderr)=$handle->cmd("touch root/email/welcome.tt",
+      '__display__');
+   my $content=<<'END';
+<\\x21DOCTYPE html PUBLIC \\x22-//W3C//DTD XHTML 1.0 Transitional//EN\\x22
+    \\x22http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\\x22>
+<html xmlns=\\x22http://www.w3.org/1999/xhtml\\x22
+      xml:lang=\\x22en\\x22
+      lang=\\x22en\\x22>
+<head>
+</head>
+<body>
+<h2 align=\\x22center\\x22>Welcome to the FullAuto API Management Dashboard.</h2>
+<p>Your username is: <span style=\\x22color: green;\\x22>[% username %]</span></p>
+<p>Your initial password is: <span style=\\x22color: red;\\x22>[% password %]</span></p>
+<p>You will be asked to change your password on first login.</p>
+</body>
+</html>
+END
+   ($stdout,$stderr)=$handle->cmd(
+      "echo -e \"$content\" > root/email/welcome.tt");
+   ($stdout,$stderr)=$handle->cmd("touch root/email/reset_password.tt",
+      '__display__');
+   my $content=<<'END';
+<\\x21DOCTYPE html PUBLIC \\x22-//W3C//DTD XHTML 1.0 Transitional//EN\\x22
+    \\x22http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\\x22>
+<html xmlns=\\x22http://www.w3.org/1999/xhtml\\x22
+      xml:lang=\\x22en\\x22
+      lang=\\x22en\\x22>
+<head>
+</head>
+<body>
+<h2 align=\\x22center\\x22>Your FullAuto API Management Dashboard Password has been Reset</h2>
+<p>Your username is: <span style=\\x22color: green;\\x22>[% username %]</span></p>
+<p>Your password is: <span style=\\x22color: red;\\x22>[% password %]</span></p>
+<p>You will be asked to change your password on first login.</p>
+</body>
+</html>
+END
+   ($stdout,$stderr)=$handle->cmd("mkdir -vp root/user",'__display__');
+   ($stdout,$stderr)=$handle->cmd(
+      "echo -e \"$content\" > root/user/list.tt");
+   ($stdout,$stderr)=$handle->cmd("touch root/user/list.tt",
+      '__display__');
+   my $content=<<'END';
+[% META title = 'FullAuto API: User Admin' %]
+ 
+<br />
+<a class=\\x22button\\x22 href=\\x22[% c.uri_for('/user/add') %]\\x22 onclick='this.blur();'><span>Add User</span></a>
+<br />
+Displaying users [% pager.first %]-[% pager.last %] of [% pager.total_entries %]
+ 
+<table>
+<tr>
+    <th>Username</th>
+    <th>Name</th>
+    <th>Email Address</th>
+</tr>
+[% WHILE (u = users.next) %]
+<tr>
+<td><a href=\\x22[% c.uri_for('/user', u.id, 'edit') %]\\x22>[% u.username %]</a></td>
+<td>[% u.name %]</td>
+<td>[% u.email_address %]</td>
+<td><a href=\\x22[% c.uri_for('/user', u.id, 'reset_password') %]\\x22>Reset Password</a></td>
+<td><a href=\\x22[% c.uri_for('/user', u.id, 'inactivate') %]\\x22>Inactivate</a></td>
+</tr>
+[% END %]
+</table>
+ 
+&lt;&lt; 
+<a href=\\x22[% c.req.uri_with({ page => pager.first_page }) %]\\x22>First</a>
+<a href=\\x22[% c.req.uri_with({ page => pager.previous_page })%]\\x22>Previous</a>
+|
+<a href=\\x22[% c.req.uri_with({ page => pager.next_page })%]\\x22>Next</a>
+<a href=\\x22[% c.req.uri_with({ page => pager.last_page }) %]\\x22>Last</a>
+&gt;&gt;
+END
+   ($stdout,$stderr)=$handle->cmd(
+      "echo -e \"$content\" > root/user/list.tt");
+   ($stdout,$stderr)=$handle->cmd("touch root/user/add.tt",
+      '__display__');
+   my $content=<<'ENDD';
+[% META title = 'FullAuto API: Add User' %]
+ 
+<div>
+<form name=\\x22[% form.name %]\\x22 action=\\x22[% c.req.uri %]\\x22 method=\\x22post\\x22>
+ 
+[% FOR field IN form.error_fields %]
+    [% FOR error IN field.errors %]
+        <p><span style=\\x22color: red;\\x22>[% field.label _ ': ' _ error %]</span></p>
+    [% END %]
+[% END %]
+ 
+<fieldset style=\\x22border: 0;\\x22>
+<table>
+<tr>
+[% f = form.field('username') %]
+<td><label for=\\x22[% f.name %]\\x22>[% f.label %]:</label></td>
+<td><input type=\\x22text\\x22 size=30 name=\\x22[% f.name %]\\x22 id=\\x22[% f.name %]\\x22 value=\\x22[% f.fif %]\\x22></td>
+</tr>
+[% PROCESS user/edit_details.tt %]
+<tr>
+    <td><input type=\\x22submit\\x22 name=\\x22submit\\x22 id=\\x22submit\\x22 value=\\x22Add\\x22 /></td>
+    <td><a href=\\x22/user/list\\x22>Users List</a></td>
+</tr>
+</fieldset>
+</table>
+</form>
+</div>
+ENDD
+   ($stdout,$stderr)=$handle->cmd(
+      "echo -e \"$content\" > root/user/add.tt");
+   ($stdout,$stderr)=$handle->cmd("touch root/user/edit.tt",
+      '__display__');
+   my $content=<<'ENDD';
+[% META title = 'FullAuto API: Edit User' %]
+ 
+<div>
+<form name=\\x22[% form.name %]\\x22 action=\\x22[% c.req.uri %]\\x22 method=\\x22post\\x22>
+ 
+[% FOR field IN form.error_fields %]
+    [% FOR error IN field.errors %]
+        <p><span style=\\x22color: red;\\x22>[% field.label _ ': ' _ error %]</span></p>
+    [% END %]
+[% END %]
+ 
+<fieldset style=\\x22border: 0;\\x22>
+<table>
+[% PROCESS user/edit_details.tt %]
+<tr>
+    <td><input type=\\x22submit\\x22 name=\\x22submit\\x22 id=\\x22submit\\x22 value=\\x22Update\\x22 /></td>
+    <td><a href=\\x22/user/list\\x22>Users List</a></td>
+</tr>
+</fieldset>
+</table>
+</form>
+</div>
+ENDD
+   ($stdout,$stderr)=$handle->cmd(
+      "echo -e \"$content\" > root/user/edit.tt");
+   ($stdout,$stderr)=$handle->cmd("touch root/user/edit_details.tt",
+      '__display__');
+   my $content=<<'ENDD';
+[% FOREACH field_name = ['name', 'email_address',
+                         'phone_number', 'mail_address'] %]
+<tr>
+[% f = form.field(field_name) %]
+<td><label class=\\x22text.label\\x22 for=\\x22[% f.name %]\\x22>[% f.label %]:</label></td>
+<td><input class=\\x22text\\x22 type=\\x22text\\x22 size=30 name=\\x22[% f.name %]\\x22 id=\\x22[% f.name %]\\x22 value=\\x22[% f.fif %]\\x22></td>
+</tr>
+[% END %]
+<tr>
+[% f = form.field('roles') %]
+<td><label for=\\x22[% f.name %]\\x22>Roles:</label></td>
+<td>[% f.render %]</td>
+</tr>
+ENDD
+   ($stdout,$stderr)=$handle->cmd(
+      "echo -e \"$content\" > root/user/edit_details.tt");
    ($stdout,$stderr)=$handle->cmd("mkdir -v db lib/FullAutoAPI/Schema",
       '__display__');
    ($stdout,$stderr)=$handle->cwd('db');
@@ -1534,6 +1708,24 @@ END
    ($stdout,$stderr)=$handle->cmd("chmod -v 777 fullautoapi.yml",'__display__');
    ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > fullautoapi.yml");
    ($stdout,$stderr)=$handle->cmd("chmod -v 644 fullautoapi.yml",'__display__');
+   $content=<<'END';
+<View::Email::Template>
+    <sender>
+        mailer Sendmail
+    </sender>
+    template_prefix email
+    <default>
+        content_type text/html
+        charset utf-8
+        view HTML
+    </default>
+</View::Email::Template>
+ 
+default_view HTML
+END
+   ($stdout,$stderr)=$handle->cmd("chmod -v 777 fullautoapi.conf",'__display__');
+   ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" >> fullautoapi.conf");
+   ($stdout,$stderr)=$handle->cmd("chmod -v 644 fullautoapi.conf",'__display__');
    ($stdout,$stderr)=$handle->cmd(
       "./script/fullautoapi_create.pl controller User",'__display__');
    ($stdout,$stderr)=$handle->cmd("mv lib/FullAutoAPI/Controller/User.pm ".
@@ -1573,6 +1765,8 @@ END
    ($stdout,$stderr)=$handle->cwd('examples');
    ($stdout,$stderr)=$handle->cmd('cp -Rv resources ../..','__display__');
    ($stdout,$stderr)=$handle->cwd('../../..');
+   ($stdout,$stderr)=$handle->cmd("./script/fullautoapi_create.pl ".
+      "view Email::Template Email::Template",'__display__');
    #
    # echo-ing/streaming files over ssh can be tricky. Use echo -e
    #          and replace these characters with thier HEX
@@ -1596,6 +1790,9 @@ use ZMQ::LibZMQ4;
 use ZMQ::Constants qw(:all);
 use YAML;
 use Carp::Assert;
+use Crypt::PassGen 'passgen';
+use FullAutoAPI::Form::AddUser  ();
+use FullAutoAPI::Form::EditUser ();
 
 use constant NBR_WORKERS    => 2;
 use constant READY          => \\x22\\\\\\\\001\\x22;
@@ -1652,7 +1849,7 @@ sub change_password : Chained('base') PathPart('change_password') Args(0) {
 sub profile : Chained('base') PathPart('profile') Args(0) {
     my (\\x24self, \\x24c) = \@_;
 
-    my \\x24form = MyApp::Form::UserProfile->new;
+    my \\x24form = FullAutoAPI::Form::UserProfile->new;
 
     \\x24c->stash(form => \\x24form);
 
@@ -1816,6 +2013,143 @@ sub single_user_DELETE {
     }
 }
 
+sub list : Chained('admin') PathPart('list') Args(0) {
+    my (\\x24self, \\x24c) = @_;
+ 
+    my \\x24users = \\x24c->model('DB::User')->search(
+        { active => 'Y'},
+        {
+            order_by => ['username'],
+            page     => (\\x24c->req->param('page') || 1),
+            rows     => 20,
+        }
+    );
+ 
+    \\x24c->stash(
+        users => \\x24users,
+        pager => \\x24users->pager,
+    );
+}
+ 
+sub add : Chained('admin') PathPart('add') Args(0) {
+    my (\\x24self, \\x24c) = @_;
+ 
+    my \\x24form = FullAutoAPI::Form::AddUser->new;
+ 
+    \\x24c->stash(form => \\x24form);
+ 
+    my \\x24user = \\x24c->model('DB::User')->new_result({});
+ 
+    my (\\x24temp_password) = passgen(NWORDS => 1, NLETT => 8);
+ 
+    \\x24user->password(\\x24temp_password);
+    \\x24user->password_expires(DateTime->now);
+    \\x24user->active('Y');
+ 
+    return unless \\x24form->process(
+        schema => \\x24c->model('DB')->schema,
+        item   => \\x24user,
+        params => \\x24c->req->body_parameters,
+    );
+ 
+    \\x24c->stash->{email} = {
+        to           => \\x24user->email_address,
+        from         => 'admin\@MyOrg.com',
+        subject      => 'Welcome to the FullAuto API',
+        content_type => 'text/html',
+        template     => 'welcome.tt',
+    };
+ 
+    \\x24c->stash(
+        username => \\x24user->username,
+        password => \\x24temp_password,
+    );
+ 
+    \\x24c->forward(\\x24c->view('Email::Template'));
+ 
+    \\x24c->res->redirect(\\x24c->uri_for(\\x24self->action_for('list'), {
+        status_msg => 'User '
+            . \\x24user->username
+            . ' created successfully'
+            . ', initial password emailed ' . 'to '
+            . \\x24user->email_address
+    }));
+}
+ 
+sub user : Chained('admin') PathPart('') CaptureArgs(1) {
+    my (\\x24self, \\x24c, \\x24user_id) = @_;
+ 
+    \\x24c->stash(user => \\x24c->model('DB::User')->find(\\x24user_id));
+}
+ 
+sub inactivate : Chained('user') PathPart('inactivate') Args(0) {
+    my (\\x24self, \\x24c) = @_;
+ 
+    my \\x24user = \\x24c->stash->{user};
+ 
+    \\x24user->update({ active => 'N' });
+ 
+    my \\x24username = \\x24user->username;
+ 
+    \\x24c->res->redirect(\\x24c->uri_for(\\x24self->action_for('list'), {
+        status_msg => \\x22User \\x24username inactivate\\x22d
+    }));
+}
+ 
+sub reset_password : Chained('user') PathPart('reset_password') Args(0) {
+    my (\\x24self, \\x24c) = @_;
+ 
+    my \\x24user = \\x24c->stash->{user};
+ 
+    my (\\x24temp_password) = passgen(NWORDS => 1, NLETT => 8);
+ 
+    \\x24user->password(\\x24temp_password);
+    \\x24user->password_expires(DateTime->now);
+    \\x24user->update;
+ 
+    \\x24c->stash->{email} = {
+        to           => \\x24user->email_address,
+        from         => 'admin@MyOrg.com',
+        subject      => 'Your FullAuto API Management Dashboard Password has been Reset',
+        content_type => 'text/html',
+        template     => 'reset_password.tt',
+    };
+ 
+    \\x24c->stash(
+        username => \\x24user->username,
+        password => \\x24temp_password,
+    );
+ 
+    \\x24c->forward(\\x24c->view('Email::Template'));
+ 
+    \\x24c->res->redirect(\\x24c->uri_for(\\x24self->action_for('list'), {
+        status_msg => 'Password reset email for '
+            . \\x24user->username
+            . ' sent to '
+            . \\x24user->email_address
+    }));
+}
+ 
+sub edit : Chained('user') PathPart('edit') Args(0) {
+    my (\\x24self, \\x24c) = @_;
+ 
+    my \\x24form = FullAutoAPI::Form::EditUser->new;
+ 
+    \\x24c->stash(form => \\x24form);
+ 
+    return unless \\x24form->process(
+        schema  => \\x24c->model('DB')->schema,
+        item_id => \\x24c->stash->{user}->id,
+        params  => \\x24c->req->body_parameters,
+    );
+ 
+    \\x24c->res->redirect(\\x24c->uri_for(\\x24self->action_for('list'), {
+        status_msg => 'User '
+            . \\x24c->stash->{user}->username
+            . ' updated successfully'
+    }));
+}
+
 1;
 END
    ($stdout,$stderr)=$handle->cwd('lib/FullAutoAPI/Controller');
